<?php
/**
 * The template for homepage posts with "Portfolio" style
 *
 * @package WordPress
 * @subpackage SOUNDER
 * @since SOUNDER 1.0
 */

sounder_storage_set('blog_archive', true);

get_header(); 

if (have_posts()) {

	sounder_show_layout(get_query_var('blog_archive_start'));

	$sounder_stickies = is_home() ? get_option( 'sticky_posts' ) : false;
	$sounder_sticky_out = sounder_get_theme_option('sticky_style')=='columns' 
							&& is_array($sounder_stickies) && count($sounder_stickies) > 0 && get_query_var( 'paged' ) < 1;
	
	// Show filters
	$sounder_cat = sounder_get_theme_option('parent_cat');
	$sounder_post_type = sounder_get_theme_option('post_type');
	$sounder_taxonomy = sounder_get_post_type_taxonomy($sounder_post_type);
	$sounder_show_filters = sounder_get_theme_option('show_filters');
	$sounder_tabs = array();
	if (!sounder_is_off($sounder_show_filters)) {
		$sounder_args = array(
			'type'			=> $sounder_post_type,
			'child_of'		=> $sounder_cat,
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 0,
			'exclude'		=> '',
			'include'		=> '',
			'number'		=> '',
			'taxonomy'		=> $sounder_taxonomy,
			'pad_counts'	=> false
		);
		$sounder_portfolio_list = get_terms($sounder_args);
		if (is_array($sounder_portfolio_list) && count($sounder_portfolio_list) > 0) {
			$sounder_tabs[$sounder_cat] = esc_html__('All', 'sounder');
			foreach ($sounder_portfolio_list as $sounder_term) {
				if (isset($sounder_term->term_id)) $sounder_tabs[$sounder_term->term_id] = $sounder_term->name;
			}
		}
	}
	if (count($sounder_tabs) > 0) {
		$sounder_portfolio_filters_ajax = true;
		$sounder_portfolio_filters_active = $sounder_cat;
		$sounder_portfolio_filters_id = 'portfolio_filters';
		?>
		<div class="portfolio_filters sounder_tabs sounder_tabs_ajax">
			<ul class="portfolio_titles sounder_tabs_titles">
				<?php
				foreach ($sounder_tabs as $sounder_id=>$sounder_title) {
					?><li><a href="<?php echo esc_url(sounder_get_hash_link(sprintf('#%s_%s_content', $sounder_portfolio_filters_id, $sounder_id))); ?>" data-tab="<?php echo esc_attr($sounder_id); ?>"><?php echo esc_html($sounder_title); ?></a></li><?php
				}
				?>
			</ul>
			<?php
			$sounder_ppp = sounder_get_theme_option('posts_per_page');
			if (sounder_is_inherit($sounder_ppp)) $sounder_ppp = '';
			foreach ($sounder_tabs as $sounder_id=>$sounder_title) {
				$sounder_portfolio_need_content = $sounder_id==$sounder_portfolio_filters_active || !$sounder_portfolio_filters_ajax;
				?>
				<div id="<?php echo esc_attr(sprintf('%s_%s_content', $sounder_portfolio_filters_id, $sounder_id)); ?>"
					class="portfolio_content sounder_tabs_content"
					data-blog-template="<?php echo esc_attr(sounder_storage_get('blog_template')); ?>"
					data-blog-style="<?php echo esc_attr(sounder_get_theme_option('blog_style')); ?>"
					data-posts-per-page="<?php echo esc_attr($sounder_ppp); ?>"
					data-post-type="<?php echo esc_attr($sounder_post_type); ?>"
					data-taxonomy="<?php echo esc_attr($sounder_taxonomy); ?>"
					data-cat="<?php echo esc_attr($sounder_id); ?>"
					data-parent-cat="<?php echo esc_attr($sounder_cat); ?>"
					data-need-content="<?php echo (false===$sounder_portfolio_need_content ? 'true' : 'false'); ?>"
				>
					<?php
					if ($sounder_portfolio_need_content) 
						sounder_show_portfolio_posts(array(
							'cat' => $sounder_id,
							'parent_cat' => $sounder_cat,
							'taxonomy' => $sounder_taxonomy,
							'post_type' => $sounder_post_type,
							'page' => 1,
							'sticky' => $sounder_sticky_out
							)
						);
					?>
				</div>
				<?php
			}
			?>
		</div>
		<?php
	} else {
		sounder_show_portfolio_posts(array(
			'cat' => $sounder_cat,
			'parent_cat' => $sounder_cat,
			'taxonomy' => $sounder_taxonomy,
			'post_type' => $sounder_post_type,
			'page' => 1,
			'sticky' => $sounder_sticky_out
			)
		);
	}

	sounder_show_layout(get_query_var('blog_archive_end'));

} else {

	if ( is_search() )
		get_template_part( 'content', 'none-search' );
	else
		get_template_part( 'content', 'none-archive' );

}

get_footer();
?>