<?php
/**
 * Shortcode: timetable
 *
 * @package WordPress
 * @subpackage ThemeREX Addons
 * @since v1.2
 */

// Don't load directly
if ( ! defined( 'TRX_ADDONS_VERSION' ) ) {
	die( '-1' );
}

// Merge shortcode's specific styles to the single stylesheet
if ( !function_exists( 'trx_addons_sc_timetable_merge_styles' ) ) {
	add_filter("trx_addons_filter_merge_styles", 'trx_addons_sc_timetable_merge_styles');
	function trx_addons_sc_timetable_merge_styles($list) {
		$list[] = TRX_ADDONS_PLUGIN_SHORTCODES . 'timetable/_timetable.scss';
		return $list;
	}
}

// trx_sc_timetable
//-------------------------------------------------------------
/*
[trx_sc_timetable id="unique_id" type="default" cat="category_slug or id" count="3" columns="3"]
*/
if ( !function_exists( 'trx_addons_sc_timetable' ) ) {
	function trx_addons_sc_timetable($atts, $content=null) {	
		$atts = trx_addons_sc_prepare_atts('trx_sc_timetable', $atts, array(
			// Individual params
			"type" => 'default',
			'hide_padding' => 0,
			"cat" => '',
			"count" => 3,
			"columns" => '',
            "offset" => 0,
			"orderby" => '',
			"order" => '',
			"ids" => '',
			"title" => '',
			"subtitle" => '',
			"description" => '',
			"link" => '',
			"link_style" => 'default',
			"link_image" => '',
			"link_text" => esc_html__('Learn more', 'trx_addons'),
			"title_align" => 'left',
			"title_style" => 'default',
			"title_tag" => '',
			// Common params
			"id" => "",
			"class" => "",
			"css" => ""
			)
		);

		if (!empty($atts['ids'])) {
			$atts['ids'] = str_replace(array(';', ' '), array(',', ''), $atts['ids']);
			$atts['count'] = count(explode(',', $atts['ids']));
		}
		$atts['count'] = max(1, (int) $atts['count']);
        $atts['offset'] = max(0, (int) $atts['offset']);
		if (empty($atts['orderby'])) $atts['orderby'] = 'date';
		if (empty($atts['order'])) $atts['order'] = 'desc';

		ob_start();
		trx_addons_get_template_part(array(
										TRX_ADDONS_PLUGIN_SHORTCODES . 'timetable/tpl.'.trx_addons_esc($atts['type']).'.php',
										TRX_ADDONS_PLUGIN_SHORTCODES . 'timetable/tpl.default.php'
										),
                                        'trx_addons_args_sc_timetable', 
                                        $atts
                                    );
		$output = ob_get_contents();
		ob_end_clean();
		
		return apply_filters('trx_addons_sc_output', $output, 'trx_sc_timetable', $atts, $content);
	}
}


// Add [trx_sc_timetable] in the VC shortcodes list
if (!function_exists('trx_addons_sc_timetable_add_in_vc')) {
	function trx_addons_sc_timetable_add_in_vc() {

        if (!trx_addons_exists_mptt()) return;

		add_shortcode("trx_sc_timetable", "trx_addons_sc_timetable");
		
		if (!trx_addons_exists_visual_composer()) return;
		
		vc_lean_map("trx_sc_timetable", 'trx_addons_sc_timetable_add_in_vc_params');
		class WPBakeryShortCode_Trx_Sc_timetable extends WPBakeryShortCode {}
	}
	add_action('init', 'trx_addons_sc_timetable_add_in_vc', 20);
}


// Return params
if (!function_exists('trx_addons_sc_timetable_add_in_vc_params')) {
	function trx_addons_sc_timetable_add_in_vc_params() {
		// If open params in VC Editor
		list($vc_edit, $vc_params) = trx_addons_get_vc_form_params('trx_sc_timetable');
		// Prepare lists
		$taxonomy = 'mp-event_category';
		$tax_obj = get_taxonomy($taxonomy);
		return apply_filters('trx_addons_sc_map', array(
				"base" => "trx_sc_timetable",
				"name" => esc_html__("timetable", 'trx_addons'),
				"description" => wp_kses_data( __("Display posts from specified category in many styles", 'trx_addons') ),
				"category" => esc_html__('ThemeREX', 'trx_addons'),
				"icon" => 'icon_trx_sc_timetable',
				"class" => "trx_sc_timetable",
				"content_element" => true,
				"is_container" => false,
				"show_settings_on_create" => true,
				"params" => array_merge(
					array(
						array(
							"param_name" => "type",
							"heading" => esc_html__("Layout", 'trx_addons'),
							"description" => wp_kses_data( __("Select shortcode's layout", 'trx_addons') ),
							'edit_field_class' => 'vc_col-sm-8',
							"admin_label" => true,
					        'save_always' => true,
							"std" => "default",
							"value" => apply_filters('trx_addons_sc_type', trx_addons_components_get_allowed_layouts('sc', 'timetable'), 'trx_sc_timetable' ),
							"mode" => 'inline',
							"return" => 'slug',
							"style" => "images",
							"type" => "icons"
						),
						array(
							"param_name" => "cat",
							"heading" => esc_html__("Category", 'trx_addons'),
							"description" => wp_kses_data( __("Select category to show posts", 'trx_addons') ),
							'edit_field_class' => 'vc_col-sm-4',
							"std" => 0,
							"value" => array_flip(trx_addons_array_merge(array(0=>sprintf(__('- %s -', 'trx_addons'), $tax_obj->label)),
																		 $taxonomy == 'category' 
																			? trx_addons_get_list_categories() 
																			: trx_addons_get_list_terms(false, $taxonomy)
																		)),
							"type" => "dropdown"
						),
                        array(
                            "param_name" => "ids",
                            "heading" => esc_html__("IDs to show", 'trx_addons'),
                            "description" => wp_kses_data( __("Comma separated IDs list to show. If not empty - parameters 'cat', 'offset' and 'count' are ignored!", 'trx_addons') ),
                            "admin_label" => true,
                            "type" => "textfield"
                        ),
                        array(
                            "param_name" => "count",
                            "heading" => esc_html__("Count", 'trx_addons'),
                            "description" => wp_kses_data( __("Specify number of items to display", 'trx_addons') ),
                            'edit_field_class' => 'vc_col-sm-4',
                            'dependency' => array(
                                'element' => 'ids',
                                'is_empty' => true
                            ),
                            "admin_label" => true,
                            "type" => "textfield"
                        ),
                        array(
                            "param_name" => "columns",
                            "heading" => esc_html__("Columns", 'trx_addons'),
                            "description" => wp_kses_data( __("Specify number of columns. If empty - auto detect by items number", 'trx_addons') ),
                            'edit_field_class' => 'vc_col-sm-4',
                            "admin_label" => true,
							'dependency' => array(
								'element' => 'type',
								'value' => array('default')
							),
                            "type" => "textfield"
                        ),
                        array(
                            "param_name" => "hide_padding",
                            "heading" => esc_html__("Hide Padding", 'trx_addons'),
                            "description" => wp_kses_data( __("Check if you want hide excerpt", 'trx_addons') ),
                            'edit_field_class' => 'vc_col-sm-4',
							'dependency' => array(
								'element' => 'type',
								'value' => array('default', 'rectangle')
							),
                            "std" => "0",
                            "value" => array(esc_html__("Hide Padding", 'trx_addons') => "1" ),
                            "type" => "checkbox"
                        ),
					),
					trx_addons_vc_add_id_param()
				)
			), 'trx_sc_timetable' );
	}
}

?>